@@ -1,19 +1,19 @@
 
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "freebsd3.3"
+#define HOST_OS "freebsd3.4"
 #define HOST_OS_NAME "freebsd3"
-#define HOST_OS_VERSION "3.3"
+#define HOST_OS_VERSION "3.4"
 #define HOST_ARCH "i386"
-#define HOST_NAME "ape.mcl.cs.columbia.edu"
+#define HOST_NAME "newt.mcl.cs.columbia.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Tue Jul  4 19:54:44 EDT 2000"
+#define CONFIG_DATE "Tue Jul  4 18:39:31 EDT 2000"
 #define PACKAGE "am-utils"
 #define VERSION "6.0.4s6"
 #define PACKAGE "am-utils"
 #define VERSION "6.0.4s6"
 #define DEBUG 1
-#define HOST_HEADER_VERSION "3.3"
+#define HOST_HEADER_VERSION "3.4"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_ALLOCA 1
@@ -252,10 +252,15 @@
 #define HAVE_FIELD_NFS_ARGS_T_VERSION 1
 #define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN 1
+#define HAVE_FGETS 1
 #define HAVE_MAP_FILE 1
+#define HAVE_DBM_OPEN 1
 #define HAVE_MAP_NDBM 1
+#define HAVE_YP_GET_DEFAULT_DOMAIN 1
 #define HAVE_MAP_NIS 1
+#define HAVE_GETPWNAM 1
 #define HAVE_MAP_PASSWD 1
+#define HAVE_OPENDIR 1
 #define HAVE_MAP_UNION 1
 #define HAVE_FS_CDFS 1
 #define HAVE_FS_MFS 1
@@ -320,4 +325,5 @@
 #define MNT2_CDFS_OPT_GENS 0x2
 #define MNT2_CDFS_OPT_NORRIP 0x1
 #define HIDE_MOUNT_TYPE "nfs"
+#define HAVE_GETMNTINFO 1
 #define USE_CONNECTED_NFS_SOCKETS 1
